# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"__jedi_toolz_var__": "config.ipynb",
         "__jedi_toolz_path__": "config.ipynb",
         "__jedi_toolz_path_method__": "config.ipynb",
         "set_path": "config.ipynb",
         "as_dict": "config.ipynb",
         "as_records": "config.ipynb",
         "select": "config.ipynb",
         "example_ini": "config.ipynb",
         "__tables__": "domo.ipynb",
         "connect": "domo.ipynb",
         "tables": "domo.ipynb",
         "get_id": "domo.ipynb",
         "query": "domo.ipynb",
         "handle_pandas": "show.ipynb",
         "text_table": "show.ipynb",
         "head": "show.ipynb",
         "transpose": "show.ipynb",
         "wrap_row": "show.ipynb",
         "wrap_table": "show.ipynb",
         "text_width": "show.ipynb",
         "get_text": "show.ipynb",
         "show": "show.ipynb",
         "names": "xlsx.ipynb",
         "texts": "xlsx.ipynb",
         "flag": "xlsx.ipynb",
         "text": "xlsx.ipynb",
         "name": "xlsx.ipynb",
         "dt": "xlsx.ipynb",
         "amt": "xlsx.ipynb",
         "gen_data": "xlsx.ipynb",
         "to_excel": "xlsx.ipynb",
         "make_test_file": "xlsx.ipynb",
         "column_format": "xlsx.ipynb",
         "default_formats": "xlsx.ipynb",
         "column_formats": "xlsx.ipynb",
         "format_sheet": "xlsx.ipynb"}

modules = ["config.py",
           "domo.py",
           "show.py",
           "xlsx.py"]

doc_url = "https://JediHero.github.io/jedi_toolz/"

git_url = "https://github.com/JediHero/jedi_toolz/tree/master/"

def custom_doc_links(name): return None
